| Title: | Functions to Set and Get the IEEE Rounding Mode |
|---|---|
| Description: | A pair of functions for getting and setting the IEEE rounding mode for floating point computations. |
| Authors: | Gianluca Amato [aut, cre] |
| Maintainer: | Gianluca Amato <[email protected]> |
| License: | GPL (>=2) |
| Version: | 0.2-2 |
| Built: | 2026-05-24 06:17:24 UTC |
| Source: | https://github.com/jandom-devel/ieeeround |
These functions get and set the rounding mode for the floating point operations.
fegetround() fesetround(rounding.mode = FE.TONEAREST) FE.DOWNWARD FE.UPWARD FE.TOWARDZERO FE.TONEARESTfegetround() fesetround(rounding.mode = FE.TONEAREST) FE.DOWNWARD FE.UPWARD FE.TOWARDZERO FE.TONEAREST
rounding.mode |
The rounding mode to set. It should be one of |
The rounding mode determines how the result of floating-point operations is treated when the result cannot be exactly represented in the significand. Various rounding modes are provided: round to nearest (the default), round up (towards positive infinity), round down (towards negative infinity), and round towards zero.
fesetround(rounding.mode) sets the rounding mode and returns 0 if
it was successfull, 1 otherwise.
fegetround() returns the current rounding mode.
Gianluca Amato [email protected]
The fenv.3 Linux manpage maintainers
fesetround(FE.UPWARD) x <- 1/5 fesetround(FE.DOWNWARD) y <- 1/5 print(x-y > 0) fesetround(FE.TONEAREST)fesetround(FE.UPWARD) x <- 1/5 fesetround(FE.DOWNWARD) y <- 1/5 print(x-y > 0) fesetround(FE.TONEAREST)